@@ -458,6 +458,8 @@ double surf_solve(double max_date)
     /* parallel version */
 #ifdef CONTEXT_THREADS
     xbt_parmap_apply(surf_parmap, (void_f_pvoid_t) surf_share_resources, model_list);
+#else
+    xbt_die("Asked to run in parallel, but no thread at hand...");
 #endif
   }
   else {
@@ -475,7 +477,7 @@ double surf_solve(double max_date)
     }
   }
 
-  XBT_DEBUG("Min for resources (remember that NS3 dont update that value) : %f", min);
+  XBT_DEBUG("Min for resources (remember that NS3 don't update that value) : %f", min);
 
   XBT_DEBUG("Looking for next trace event");
 
