@@ -644,11 +644,11 @@ static void xbt_log_connect_categories(void)
   XBT_LOG_CONNECT(msg);
   XBT_LOG_CONNECT(msg_action);
   XBT_LOG_CONNECT(msg_gos);
+  XBT_LOG_CONNECT(msg_io);
   XBT_LOG_CONNECT(msg_kernel);
   XBT_LOG_CONNECT(msg_mailbox);
   XBT_LOG_CONNECT(msg_process);
   XBT_LOG_CONNECT(msg_task);
-  XBT_LOG_CONNECT(msg_io);
 
   /* simdag */
   XBT_LOG_CONNECT(sd);
@@ -954,7 +954,7 @@ int _xbt_log_cat_init(xbt_log_category_t category,
         cpp = cpp->nextSibling;
       }
 
-      XBT_DEBUG("Childs of %s: %s; nextSibling: %s",
+      XBT_DEBUG("Children of %s: %s; nextSibling: %s",
              category->parent->name, res,
              (category->parent->nextSibling ?
               category->parent->nextSibling->name : "none"));
